@@ -1,24 +1,24 @@
 <?
 /*
- *   This file is part of WCOMPTA.
+ *   This file is part of PhpCompta.
  *
- *   WCOMPTA is free software; you can redistribute it and/or modify
+ *   PhpCompta is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
  *
- *   WCOMPTA is distributed in the hope that it will be useful,
+ *   PhpCompta is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with WCOMPTA; if not, write to the Free Software
+ *   along with PhpCompta; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-// Auteur Dany De Bontridder ddebontridder@yahoo.fr
-// $Revision: 1.7 $
+// Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
+// $Revision: 1.12 $
 
 /* function ViewImp
  * Purpose : Create the form where the period
@@ -80,14 +80,16 @@ function ViewImp($p_array,$p_cn) {
   echo "</DIV>";
 }
 /* function Imp
- * Purpose :
+ * Purpose : Show the html printing result 
+ *           
  * 
  * parm : 
- *	- 
+ *	-  array
+ *      -  db connection
  * gen :
- *	-
+ *	- none
  * return:
- *	-
+ *	- ImpHtml
  *
  */ 
 function Imp($p_array,$p_cn) {
@@ -132,6 +134,7 @@ function ImpHtml($p_array,$p_cn)
                      fo_formula,
                      fr_label from form 
                       inner join formdef on fr_id=fo_fr_id
+                     where fo_fr_id=$p_id
                      order by fo_pos");
     $Max=pg_NumRows($Res);
     if ($Max==0) return $ret="";
@@ -167,17 +170,24 @@ function ImpHtml($p_array,$p_cn)
       if ( count($array) == 0) continue;
       $ret.=sprintf("<H2 class=\"info\">%d %s</H2>",
 		    $poste[$i],GetPosteLibelle($p_cn,$poste[$i],1));
-      $ret.="<TABLE border=0 >";
+      $ret.="<TABLE style=\"border-bottom-style:solid; border-width:2px\" >";
+      $i=0;
       foreach ($array as $col=>$element) {
-	$ret.="<TR>";
-	$ret.=sprintf("<TD>%s</TD>",$element['jr_internal']);
+	$i++;
+	if ( $i %2 == 0) 
+	  $ret.="<tr class=\"even\">";
+	else
+	  $ret.="<TR class=\"odd\">";
 	$ret.=sprintf("<TD>%s</TD>",$element['j_date']);
-	$ret.=sprintf("<TD>jrn:%s</TD>",$element['jrn_name']);
+	$ret.=sprintf("<TD>%s</TD>",$element['jr_internal']);
+	//	$ret.=sprintf("<TD>jrn:%s</TD>",$element['jrn_name']);
 	$ret.=sprintf("<TD>%s</TD>",$element['description']);
 	if ( $element['j_debit']=='t') {
-	  $ret.=sprintf("<TD> debit</TD><TD ALIGN=\"right\">   % 8.2f</TD>",$element['montant']);
+	  $ret.=sprintf("<TD> debit</TD><TD ALIGN=\"right\">   % 8.2f</TD> $colvide",
+			$element['deb_montant']);
 	} else {
-	  $ret.=sprintf("<TD>credit</TD> $colvide <TD ALIGN=\"right\">  % 8.2f</TD>",$element['montant']);
+	  $ret.=sprintf("<TD>credit</TD> $colvide <TD ALIGN=\"right\">  % 8.2f</TD>",
+			$element['cred_montant']);
 	  
 	}
 	$ret.="</TR>";
@@ -189,7 +199,7 @@ function ImpHtml($p_array,$p_cn)
 		    $tot_deb,
 		    $tot_cred);
       $ret.="</TABLE>";
-      $ret.="Total dbit :".$tot_deb."   Total Crdit:".$tot_cred;     
+      $ret.="<p>Total dbit :".$tot_deb."   Total Crdit:".$tot_cred."</p>";     
       if ( $tot_deb > $tot_cred ) {
       	$solde_t="D"; 
 	$solde=$tot_deb-$tot_cred;
@@ -197,7 +207,7 @@ function ImpHtml($p_array,$p_cn)
       	$solde_t="C";
 	$solde=$tot_cred-$tot_deb;
 	}
-      $ret.=" <B> Solde  $solde_t = ".$solde."</B>";
+      $ret.=" <p><B> Solde  $solde_t = ".$solde."</B></p>";
     }// for i
     return $ret;
   }//poste
@@ -255,10 +265,11 @@ function ImpHtml($p_array,$p_cn)
 function GetDataPoste($p_cn,$p_poste,$p_condition)
 {
   $Res=ExecSql($p_cn,"select to_char(j_date,'DD.MM.YYYY') as j_date,".
-	       "to_char(j_montant,'999999999.99') as montant,".
+	       "case when j_debit='t' then to_char(j_montant,'999999999.99') else ' ' end as deb_montant,".
+	       "case when j_debit='f' then to_char(j_montant,'999999999.99') else ' ' end as cred_montant,".
 	       " jr_comment as description,jrn_def_name as jrn_name,".
-	       "j_debit, jr_internal, ".
-	       " case when j_debit='t' then 'debit' else 'credit' end as debit".
+	       "j_debit, jr_internal ".
+// 	       " case when j_debit='t' then 'debit' else 'credit' end as debit".
 	       " from jrnx left join jrn_def on jrn_def_id=j_jrn_def ".
 	       " left join jrn on jr_grpt_id=j_grpt".
 	       " where j_poste=".$p_poste." and ".$p_condition.
@@ -271,9 +282,9 @@ function GetDataPoste($p_cn,$p_poste,$p_condition)
   for ($i=0;$i<$Max;$i++) {
     $array[]=pg_fetch_array($Res,$i);
     if ($array[$i]['j_debit']=='t') {
-      $tot_deb+=$array[$i]['montant'] ;
+      $tot_deb+=$array[$i]['deb_montant'] ;
     } else {
-      $tot_cred+=$array[$i]['montant'] ;
+      $tot_cred+=$array[$i]['cred_montant'] ;
     }
   }
   return array($array,$tot_deb,$tot_cred);
@@ -409,6 +420,8 @@ function CreatePeriodeCond($p_periode,$p_field=" j_tech_per") {
  */ 
 function GetDataJrnPdf($p_cn,$p_array,$p_limit,$p_offset)
 {
+  echo_debug("GetDataJrnPdf");
+
   if ( !isset ($p_array['periode']) ) return NO_PERIOD_SELECTED;
 
   if ( $p_array['filter']==YES) {
@@ -425,7 +438,7 @@ function GetDataJrnPdf($p_cn,$p_array,$p_limit,$p_offset)
 		 "jr_grpt_id=j_grpt ".
 		 " left join tmp_pcmn on pcm_val=j_poste ".
                 " where j_jrn_def=".$p_array['p_id'].
-	       " and ".$cond." order by j_id,j_date::date,j_grpt,j_debit desc".
+	       " and ".$cond." order by j_date::date asc,jr_internal,j_debit desc".
 	       " limit ".$p_limit." offset ".$p_offset);
     }else {
       // Journaux centraliss
@@ -454,7 +467,7 @@ function GetDataJrnPdf($p_cn,$p_array,$p_limit,$p_offset)
     }
   } else {
     // Grand Livre
-    if ( $p_array['central']=='no' ) {
+    if (! isset($p_array['central'])) {
       // Non centralis
       $cond=CreatePeriodeCond($p_array['periode']);
       $Res=ExecSql($p_cn,"select j_id,to_char(j_date,'DD.MM.YYYY') as j_date,
